@@ -165,6 +165,28 @@ const nofreefns = Set{String}((
     "ijl_array_to_string",
     "pcre2_jit_compile_8",
     "memmove",
+    "cuStreamCreate",
+    "cuCtxGetCurrent",
+    "cuStreamGetCaptureInfo",
+    "cuStreamQuery",
+    "cuStreamSynchronize",
+    "cuMemGetInfo_v2",
+    "cuMemPoolCreate",
+    "cuDeviceSetMemPool",
+    "cuMemPoolSetAttribute",
+    "jl_gc_safe_enter",
+    "jl_gc_safe_leave",
+    "ijl_gc_is_in_finalizer",
+    "ijl_get_task_threadpoolid",
+    "jl_rand_ptls",
+    "ijl_wakeup_thread",
+    "ijl_safe_printf",
+    "ijl_threadpoolid",
+    "ijl_task_get_next",
+    "ijl_switch",
+    "ijl_process_events",
+    "utf8proc_category",
+    "jl_clock_now",
 ))
 
 const inactivefns = Set{String}((
@@ -514,6 +536,7 @@ function annotate!(mod::LLVM.Module)
         end
     end
 
+
     for fname in (
         "jl_f_getfield",
         "ijl_f_getfield",
